@@ -129,7 +129,7 @@ def lead_lag_indicator(data = None, lead=3, lag=5, contravariant = -1., **kwargs
     else :
         return contravariant
 
-def volume_weigthed_high_low_vol_perc(data = None, vol_threshold = 0.8, up_trend_threshold=0.8, low_trend_threshold=0.2, contravariant = -1., lag = 2, **kwargs):
+def volume_weigthed_high_low_vol(data = None, vol_threshold = 0.8, up_trend_threshold=0.8, low_trend_threshold=0.2, contravariant = -1., lag = 2, **kwargs):
     ## aggregating the volumes by lag
     all_indices = list(reversed(range(len(data) - 1, 0, -lag)))
     data['aggregated_indice'] = np.nan
